"use strict";

var _require = require("gatsby-page-utils"),
    createPath = _require.createPath,
    validatePath = _require.validatePath,
    ignorePath = _require.ignorePath;

var _require2 = require("./create-client-only-page"),
    createClientOnlyPage = _require2.createClientOnlyPage;

var _require3 = require("./create-pages-from-collection-builder"),
    createPagesFromCollectionBuilder = _require3.createPagesFromCollectionBuilder;

var systemPath = require("path");

var fs = require("fs-extra");

var pathIsCCollectionBuilder = function pathIsCCollectionBuilder(path) {
  if (fs.existsSync(path) === false) return false;
  var js = fs.readFileSync(path).toString();
  return js.includes("createPagesFromData");
};

var pathIsClientOnlyRoute = function pathIsClientOnlyRoute(path) {
  return /\[.*\]/.test(path);
};

exports.createPage = function (filePath, pagesDirectory, actions, ignore, graphql) {
  // Filter out special components that shouldn't be made into
  // pages.
  if (!validatePath(filePath)) {
    return;
  } // Filter out anything matching the given ignore patterns and options


  if (ignorePath(filePath, ignore)) {
    return;
  }

  var absolutePath = systemPath.join(pagesDirectory, filePath);

  if (pathIsCCollectionBuilder(absolutePath)) {
    createPagesFromCollectionBuilder(absolutePath, actions, graphql);
    return;
  }

  if (pathIsClientOnlyRoute(absolutePath)) {
    createClientOnlyPage(absolutePath, actions);
    return;
  } // Create page object


  var createdPath = createPath(filePath);
  var page = {
    path: createdPath,
    component: absolutePath
  }; // Add page

  actions.createPage(page);
};